<?php
declare(strict_types=1);

namespace App\Entity\QRCode;

use Symfony\Component\Validator\Constraints as Assert;

/**
 * Payment identification for QR code
 */
class QRCodePaymentIdentification {
    #[Assert\NotBlank(message: 'messages.fill_value')]
    #[Assert\Length( // <<< Ano, mohl jsem si napsat vlastni validator ...
        min: 1,
        max: 10,
        minMessage: 'messages.not_variable_symbol',
        maxMessage: 'messages.not_variable_symbol',
    )] // https://en.wikipedia.org/wiki/Variable_symbol
    #[Assert\Positive(
        message: 'messages.not_variable_symbol',
    )]
    private string $variableSymbol;

    #[Assert\NotBlank(message: 'messages.fill_value')]
    #[Assert\Length(
        min: 1,
        max: 10,
        minMessage: 'messages.not_specific_symbol',
        maxMessage: 'messages.not_specific_symbol',
    )] // https://cs.wikipedia.org/wiki/Specifick%C3%BD_symbol
    #[Assert\Positive(
        message: 'The {{ value }} is not a variable symbol.',
    )]
    private string $specificSymbol;

    #[Assert\NotBlank(message: 'messages.fill_value')]
    #[Assert\Length(
        min: 1,
        max: 10,
        minMessage: 'messages.not_constant_symbol',
        maxMessage: 'messages.not_constant_symbol',
    )]  // https://www.hyponamiru.cz/en/glossary/constant-symbol/
    #[Assert\Positive(
        message: 'messages.not_constant_symbol',
    )]
    private string $constantSymbol;

    public function getVariableSymbol(): string
    {
        return $this->variableSymbol;
    }

    public function setVariableSymbol(string $variableSymbol): void
    {
        $this->variableSymbol = $variableSymbol;
    }

    public function getSpecificSymbol(): string
    {
        return $this->specificSymbol;
    }

    public function setSpecificSymbol(string $specificSymbol): void
    {
        $this->specificSymbol = $specificSymbol;
    }

    public function getConstantSymbol(): string
    {
        return $this->constantSymbol;
    }

    public function setConstantSymbol(string $constantSymbol): void
    {
        $this->constantSymbol = $constantSymbol;
    }


}
